@@ -3,7 +3,7 @@
 // GkClient.cxx
 //
 // Copyright (c) Citron Network Inc. 2001-2003
-// Copyright (c) 2002-2010, Jan Willamowius
+// Copyright (c) 2002-2011, Jan Willamowius
 //
 // This work is published under the GNU Public License version 2 (GPLv2)
 // see file COPYING for details.
@@ -683,7 +683,7 @@ bool STUNClient::OpenSocketA(UDPSocket & socket, PortInfo & portInfo, const PIPS
       if (status)
         break;
       if (portInfo.currentPort == startPort) {
-        PTRACE(3, "STUN\tListen failed on " << m_interface << ":" << portInfo.currentPort);
+        PTRACE(3, "STUN\tListen failed on " << AsString(m_interface, portInfo.currentPort));
         return false;
       }
     } 
@@ -869,6 +869,8 @@ bool GRQRequester::SendRequest(const Address & addr, WORD pt, int r)
 	for (std::vector<Address>::iterator i = GKHome.begin(); i != GKHome.end(); ++i) {
 		if ((IsLoopback(addr) || IsLoopback(*i)) && addr != *i)
 			continue;
+		if (addr.GetVersion() != i->GetVersion())
+			continue;
 		GkInterface * inter = m_rasSrv->SelectInterface(*i);
 		if (inter == NULL)
 			return false;
@@ -946,7 +948,7 @@ GkClient::GkClient()
 	m_ttl(GkConfig()->GetInteger(EndpointSection, "TimeToLive", DEFAULT_TTL)),
 	m_timer(0),
 	m_retry(GkConfig()->GetInteger(EndpointSection, "RRQRetryInterval", DEFAULT_RRQ_RETRY)),
-	m_rewriteInfo(NULL), m_natClient(NULL),
+	m_authMode(-1), m_rewriteInfo(NULL), m_natClient(NULL),
 	m_parentVendor(ParentVendor_GnuGk), m_endpointType(EndpointType_Gateway),
 	m_discoverParent(true)
 #ifdef HAS_H46023
