@@ -194,13 +194,19 @@ template<> H225_ArrayOf_AliasAddress *FacilityRequest::GetAliases()
 bool Policy::Handle(SetupRequest& request)
 {
 	if( IsActive() ) {
+#if PTRACING
 		const PString tagname = request.GetWrapper()->GetTagName();
 		const unsigned crv = request.GetWrapper()->GetCallReference();
 		PTRACE(5, "ROUTING\tChecking policy " << m_name
-			<< " for request " << tagname << " CRV=" << crv);
+			<< " for request " << tagname << " CRV=" << crv
+			);
+#endif
 		if (OnRequest(request)) {
+#if PTRACING
 			PTRACE(5, "ROUTING\tPolicy " << m_name
-				<< " applied to the request " << tagname << " CRV=" << crv);
+				<< " applied to the request " << tagname << " CRV=" << crv
+				);
+#endif
 			return true;
 		}
 	}
@@ -210,14 +216,19 @@ bool Policy::Handle(SetupRequest& request)
 bool Policy::Handle(FacilityRequest& request)
 {
 	if( IsActive() ) {
+#if PTRACING
 		const PString tagname = request.GetWrapper()->GetTagName();
 		const unsigned crv = request.GetWrapper()->GetCallReference();
 		PTRACE(5, "ROUTING\tChecking policy " << m_name
 			<< " for request " << tagname << " CRV=" << crv
 			);
+#endif
 		if (OnRequest(request)) {
+#if PTRACING
 			PTRACE(5, "ROUTING\tPolicy " << m_name
-				<< " applied to the request " << tagname << " CRV=" << crv);
+				<< " applied to the request " << tagname << " CRV=" << crv
+				);
+#endif
 			return true;
 		}
 	}
@@ -357,7 +368,7 @@ bool AliasesPolicy::OnRequest(FacilityRequest & request)
 }
 
 
-std::map<PString, PString> ExplicitPolicy::m_destMap;
+std::map<PString, H225_TransportAddress> ExplicitPolicy::m_destMap;
 
 ExplicitPolicy::ExplicitPolicy()
 {
@@ -372,22 +383,14 @@ void ExplicitPolicy::OnReload()
 		PString src = mappings.GetKeyAt(i);
 		PString dest = mappings.GetDataAt(i);
 		H225_TransportAddress srcAddr;
-		if (GetTransportAddress(src, GK_DEF_ENDPOINT_SIGNAL_PORT, srcAddr)) {
+		if (GetTransportAddress(src, 1720, srcAddr)) {
 			if (!dest.IsEmpty()) {
-				if (IsIPAddress(dest)) {
-					// test parse IP, but store again as string
-					H225_TransportAddress destAddr;
-					if (GetTransportAddress(dest, GK_DEF_ENDPOINT_SIGNAL_PORT, destAddr)) {
-						m_destMap[AsDotString(srcAddr, false)] = AsDotString(destAddr, false);
-					} else {
-						PTRACE(1, "Error parsing dest entry in [Routing::Explicit]: " << src << "=" << dest);
-					}
+				H225_TransportAddress destAddr;
+				if (GetTransportAddress(dest, 1720, destAddr)) {
+					m_destMap[AsDotString(srcAddr, false)] = destAddr;
 				} else {
-					// store anything else as string, will be used as alias
-					m_destMap[AsDotString(srcAddr, false)] = dest;
+					PTRACE(1, "Error parsing dest entry in [Routing::Explicit]: " << src << "=" << dest);
 				}
-			} else {
-				PTRACE(1, "Error: Empty dest entry in [Routing::Explicit]: " << src << "=");
 			}
 		} else {
 			PTRACE(1, "Error parsing src entry in [Routing::Explicit]: " << src << "=" << dest);
@@ -395,72 +398,13 @@ void ExplicitPolicy::OnReload()
 	}
 }
 
-void ExplicitPolicy::MapDestination(H225_AdmissionRequest & arq)
+void ExplicitPolicy::MapDestination(H225_TransportAddress & addr)
 {
-	H225_TransportAddress & addr = arq.m_destCallSignalAddress;
 	PString orig = AsDotString(addr, false);	// original IP without port
-	std::map<PString, PString>::const_iterator i = m_destMap.find(orig);
+	std::map<PString, H225_TransportAddress>::const_iterator i = m_destMap.find(orig);
 	if (i != m_destMap.end()) {
-		PString newDest = i->second;
-		if (IsIPAddress(newDest)) {
-			// just rewrite the IP
-			H225_TransportAddress destAddr;
-			GetTransportAddress(newDest, GK_DEF_ENDPOINT_SIGNAL_PORT, destAddr); // ignore result, we have parsed these before
-			addr = destAddr;
-		} else {
-			// delete IP and set a new destination alias
-			arq.RemoveOptionalField(H225_AdmissionRequest::e_destCallSignalAddress);
-			arq.IncludeOptionalField(H225_AdmissionRequest::e_destinationInfo);
-			arq.m_destinationInfo.SetSize(1);
-			H323SetAliasAddress(newDest, arq.m_destinationInfo[0]);
-		}
-		PTRACE(4, "[Routing::Explicit]: map destination " << orig << " to " << newDest);
-	}
-}
-
-void ExplicitPolicy::MapDestination(H225_Setup_UUIE & setupBody)
-{
-	H225_TransportAddress & addr = setupBody.m_destCallSignalAddress;
-	PString orig = AsDotString(addr, false);	// original IP without port
-	std::map<PString, PString>::const_iterator i = m_destMap.find(orig);
-	if (i != m_destMap.end()) {
-		PString newDest = i->second;
-		if (IsIPAddress(newDest)) {
-			// just rewrite the IP
-			H225_TransportAddress destAddr;
-			GetTransportAddress(newDest, GK_DEF_ENDPOINT_SIGNAL_PORT, destAddr); // ignore result, we have parsed these before
-			addr = destAddr;
-		} else {
-			// delete IP and set a new destination alias
-			setupBody.RemoveOptionalField(H225_Setup_UUIE::e_destCallSignalAddress);
-			setupBody.IncludeOptionalField(H225_Setup_UUIE::e_destinationAddress);
-			setupBody.m_destinationAddress.SetSize(1);
-			H323SetAliasAddress(newDest, setupBody.m_destinationAddress[0]);
-		}
-		PTRACE(4, "[Routing::Explicit]: map destination " << orig << " to " << newDest);
-	}
-}
-
-void ExplicitPolicy::MapDestination(H225_Facility_UUIE & facilityBody)
-{
-	H225_TransportAddress & addr = facilityBody.m_alternativeAddress;
-	PString orig = AsDotString(addr, false);	// original IP without port
-	std::map<PString, PString>::const_iterator i = m_destMap.find(orig);
-	if (i != m_destMap.end()) {
-		PString newDest = i->second;
-		if (IsIPAddress(newDest)) {
-			// just rewrite the IP
-			H225_TransportAddress destAddr;
-			GetTransportAddress(newDest, GK_DEF_ENDPOINT_SIGNAL_PORT, destAddr); // ignore result, we have parsed these before
-			addr = destAddr;
-		} else {
-			// delete IP and set a new destination alias
-			facilityBody.RemoveOptionalField(H225_Facility_UUIE::e_alternativeAddress);
-			facilityBody.IncludeOptionalField(H225_Facility_UUIE::e_alternativeAliasAddress);
-			facilityBody.m_alternativeAliasAddress.SetSize(1);
-			H323SetAliasAddress(newDest, facilityBody.m_alternativeAliasAddress[0]);
-		}
-		PTRACE(4, "[Routing::Explicit]: map destination " << orig << " to " << newDest);
+		addr = i->second;
+		PTRACE(4, "[Routing::Explicit]: map destination " << orig << " to " << AsDotString(i->second));
 	}
 }
 
@@ -468,12 +412,11 @@ bool ExplicitPolicy::OnRequest(AdmissionRequest & request)
 {
 	H225_AdmissionRequest & arq = request.GetRequest();
 	if (arq.HasOptionalField(H225_AdmissionRequest::e_destCallSignalAddress)) {
-		MapDestination(arq);
-		// check if the mapping removed the destination IP
-		if (!arq.HasOptionalField(H225_AdmissionRequest::e_destCallSignalAddress))
-			return false;
+		MapDestination(arq.m_destCallSignalAddress);
 		Route route(m_name, arq.m_destCallSignalAddress);
-		route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(route.m_destAddr);
+		route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(
+			route.m_destAddr
+			);
 #ifdef HAS_H46023
         if (!route.m_destEndpoint && 
            arq.HasOptionalField(H225_AdmissionRequest::e_genericData) &&
@@ -496,7 +439,9 @@ bool ExplicitPolicy::OnRequest(SetupRequest & request)
 	if (setup.HasOptionalField(H225_Setup_UUIE::e_destCallSignalAddress)) {
 		// don't map IP here, for Setup already done in OnSetup()
 		Route route(m_name, setup.m_destCallSignalAddress);
-		route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(route.m_destAddr);
+		route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(
+			route.m_destAddr
+			);
 		return request.AddRoute(route);
 	}
 	return false;
@@ -506,12 +451,11 @@ bool ExplicitPolicy::OnRequest(FacilityRequest & request)
 {
 	H225_Facility_UUIE & facility = request.GetRequest();
 	if (facility.HasOptionalField(H225_Facility_UUIE::e_alternativeAddress)) {
-		MapDestination(facility);
-		// check if the mapping removed the destination IP
-		if (!facility.HasOptionalField(H225_Facility_UUIE::e_alternativeAddress))
-			return false;
+		MapDestination(facility.m_alternativeAddress);
 		Route route(m_name, facility.m_alternativeAddress);
-		route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(route.m_destAddr);
+		route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(
+			route.m_destAddr
+			);
 		return request.AddRoute(route);
 	}
 	return false;
@@ -936,20 +880,20 @@ bool VirtualQueue::IsDestinationVirtualQueue(
 bool VirtualQueue::RouteToAlias(
 	/// aliases for the routing target (an agent that the call will be routed to) 
 	/// that will replace the original destination info
-	const H225_ArrayOf_AliasAddress & agent,
+	const H225_ArrayOf_AliasAddress& agent,
 	/// ip that will replace the destinationCallSignalAddress (RouteToGateway)
 	/// used only if set (!= NULL)
-	const PString & destinationip,
+	const PString& destinationip,
 	/// identifier of the endpoint associated with the route request
-	const PString & callingEpId, 
+	const PString& callingEpId, 
 	/// CRV of the call associated with the route request
 	unsigned crv,
 	/// callID of the call associated with the route request
-	const PString & callID,
+	const PString& callID,
 	// outgoing IP or empty
-	const PString & bindIP,
+	const PString& bindIP,
 	// caller ID or empty
-	const PString & callerID,
+	const PString& callerID,
 	/// should this call be rejected
 	bool reject
 	)
@@ -1023,7 +967,7 @@ bool VirtualQueue::RouteToAlias(
 	)
 {
 	H225_ArrayOf_AliasAddress alias;
-	if (targetAlias != "" && targetAlias != "-") {
+	if (targetAlias != "") {
 		alias.SetSize(1);
 		H323SetAliasAddress(targetAlias, alias[0]);
 	}
@@ -1257,9 +1201,7 @@ bool VirtualQueuePolicy::OnRequest(SetupRequest & request)
 		PString * bindIP = new PString();
 		PString * callerID = new PString();
 		PString callid = AsString(setup.m_callIdentifier.m_guid);
-		PString src;
-		if (setup.HasOptionalField(H225_Setup_UUIE::e_sourceAddress))
-			src = AsString(setup.m_sourceAddress);
+		PString src = AsString(setup.m_sourceAddress);
 		PIPSocket::Address localAddr;
 		WORD localPort;
 		request.GetWrapper()->GetLocalAddr(localAddr, localPort);
@@ -1359,8 +1301,10 @@ NumberAnalysisPolicy::NumberAnalysisPolicy()
 	stable_sort(m_prefixes.begin(), m_prefixes.end(), PrefixGreater());
 	
 	PTRACE(5, "ROUTING\t" << m_name << " policy loaded with " << m_prefixes.size()
-		<< " prefix entries");
-
+		<< " prefix entries"
+		);
+		
+#if PTRACING
 	if (PTrace::CanTrace(6)) {
 		ostream &strm = PTrace::Begin(6, __FILE__, __LINE__);
 		strm << "ROUTING\t" << m_name << " policy prefixes:" << endl;
@@ -1370,6 +1314,7 @@ NumberAnalysisPolicy::NumberAnalysisPolicy()
 				<< m_prefixes[i].m_maxLength << endl;
 		PTrace::End(strm);
 	}
+#endif /* PTRACING */
 }
 
 bool NumberAnalysisPolicy::OnRequest(AdmissionRequest & request)
@@ -1656,9 +1601,7 @@ bool SqlPolicy::OnRequest(SetupRequest & request)
 	WORD localPort;
 	request.GetWrapper()->GetLocalAddr(localAddr, localPort);
 	PString calledIP = localAddr;	// TODO: only correct if a gatekeeper IP was called, should we use explicit IP if present ?
-	PString caller;
-	if (setup.HasOptionalField(H225_Setup_UUIE::e_sourceAddress))
-		caller = AsString(setup.m_sourceAddress, FALSE);
+	PString caller = AsString(setup.m_sourceAddress, FALSE);
 	PString callingStationId = request.GetCallingStationId();
 	PString callid = AsString(setup.m_callIdentifier.m_guid);
 	PString messageType = "Setup";
