@@ -15,7 +15,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef ROUTING_H
-#define ROUTING_H "@(#) $Id: Routing.h,v 1.60 2011/12/05 21:33:51 willamowius Exp $"
+#define ROUTING_H "@(#) $Id: Routing.h,v 1.58 2011/11/18 14:40:02 willamowius Exp $"
 
 #include <map>
 #include <list>
@@ -183,14 +183,20 @@ public:
 	template <class R> bool HandleRas(Request<R,RasMsg> & request)
 	{
 		if( IsActive() ) {
+#if PTRACING
 			const char* tagname = request.GetWrapper()
 				? request.GetWrapper()->GetTagName() : "unknown";
 			const unsigned seqnum = request.GetRequest().m_requestSeqNum.GetValue();
 			PTRACE(5,"ROUTING\tChecking policy "<<m_name
-				<<" for the request "<<tagname<<' '<<seqnum);
+				<<" for the request "<<tagname<<' '<<seqnum
+				);
+#endif
 			if( OnRequest(request) ) {
+#if PTRACING
 				PTRACE(5,"ROUTING\tPolicy "<<m_name
-					<<" applied to the request "<<tagname<<' '<<seqnum);
+					<<" applied to the request "<<tagname<<' '<<seqnum
+					);
+#endif
 				return true;
 			}
 		}
@@ -225,9 +231,7 @@ class ExplicitPolicy : public Policy {
 public:
 	ExplicitPolicy();
 
-	static void MapDestination(H225_AdmissionRequest & arq);
-	static void MapDestination(H225_Setup_UUIE & setupBody);
-	static void MapDestination(H225_Facility_UUIE & facility);
+	static void MapDestination(H225_TransportAddress & addr);
 	static void OnReload();
 
 protected:
@@ -236,7 +240,7 @@ protected:
 	virtual bool OnRequest(SetupRequest &);
 	virtual bool OnRequest(FacilityRequest &);
 
-	static std::map<PString, PString> m_destMap;
+	static std::map<PString, H225_TransportAddress> m_destMap;
 };
 
 
