@@ -63,8 +63,8 @@ NetworkAddress::NetworkAddress(
 }
 
 NetworkAddress::NetworkAddress(
-	const PIPSocket::Address &addr,
-	const PIPSocket::Address &nm
+	const PIPSocket::Address & addr,
+	const PIPSocket::Address & nm
 	) : m_netmask(nm)
 {
 	// normalize the address
@@ -330,6 +330,7 @@ void Toolkit::RouteTable::InitTable()
 	}
 #endif
 
+#if PTRACING
 	for (RouteEntry *entry = rtable_begin; entry != rtable_end; ++entry) {
 		PTRACE(2, "Network=" << NetworkAddress(entry->GetNetwork(), entry->GetNetMask()).AsString() <<
 				", IP=" << entry->GetDestination());
@@ -345,6 +346,7 @@ void Toolkit::RouteTable::InitTable()
 	if (defAddr.IsLoopback()) {
 		PTRACE(1, "WARNING: Your default IP=" << defAddr << " is a loopback address. That probably won't work!");
 	}
+#endif
 }
 
 // get default route from route table, because GetGatewayAddress() is broken until PTLib 2.11.1
@@ -795,6 +797,16 @@ void Toolkit::RewriteTool::LoadConfig(PConfig *config)
 	m_Rewrite->AddSection(config,AliasRewriteSection);
 }
 
+bool Toolkit::IsNumeric(const PString & s) 
+{
+	PINDEX j;
+	for (j = 0; j < s.GetLength(); ++j)
+		if (!isdigit(static_cast<unsigned char>(s[j])))
+			break;
+
+	return (j >= s.GetLength());
+}
+
 bool Toolkit::RewriteTool::RewritePString(PString & s) const
 {
 	bool changed = false;
@@ -1569,7 +1581,7 @@ PConfig* Toolkit::ReloadConfig()
 	// update the gatekeeper name, in case it was set in the SQL config
 	m_GKName = m_Config->GetString("Name", "OpenH323GK");
 #ifdef HAS_H235_MEDIA
-	m_H235HalfCallMediaEnabled	= m_Config->GetBoolean(RoutedSec, "EnableH235HalfCallMedia", 0);
+	m_H235MediaEnabled	= m_Config->GetBoolean(RoutedSec, "EnableH235Media", 0);
 #endif
 #ifdef HAS_H46018
 	m_H46018Enabled	= m_Config->GetBoolean(RoutedSec, "EnableH46018", 0);
@@ -2404,7 +2416,7 @@ bool Toolkit::RewriteE164(H225_AliasAddress & alias)
 	if (changed) {
 		if (E164.Find("@") != P_MAX_INDEX)
 			H323SetAliasAddress(E164, alias,H225_AliasAddress::e_url_ID);
-		else if (IsValidE164(E164))
+		else if (IsNumeric(E164))
 			H323SetAliasAddress(E164, alias, H225_AliasAddress::e_dialedDigits);
 		else if (alias.GetTag() != H225_AliasAddress::e_partyNumber)
 			H323SetAliasAddress(E164, alias, H225_AliasAddress::e_h323_ID);
