@@ -12,7 +12,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef TOOLKIT_H
-#define TOOLKIT_H "@(#) $Id: Toolkit.h,v 1.90 2011/12/21 17:02:07 willamowius Exp $"
+#define TOOLKIT_H "@(#) $Id: Toolkit.h,v 1.88 2011/11/10 11:03:46 willamowius Exp $"
 
 #include <vector>
 #include <map>
@@ -331,6 +331,7 @@ class Toolkit : public Singleton<Toolkit>
 	bool RewriteE164(H225_ArrayOf_AliasAddress & aliases);
 
 	bool RewritePString(PString & s) { return m_Rewrite.RewritePString(s); }
+	bool IsNumeric(const PString & s);
 
 	// Class to allow correct use of STL inside PDictionary type
 	class GWRewriteEntry : public PObject {
@@ -367,7 +368,7 @@ class Toolkit : public Singleton<Toolkit>
 	bool IsGKHome(const PIPSocket::Address & addr) const;
 
 #ifdef HAS_H235_MEDIA
-	bool IsH235HalfCallMediaEnabled() const { return m_H235HalfCallMediaEnabled; }
+	bool IsH235MediaEnabled() const { return m_H235MediaEnabled; }
 #endif
 
 	bool isBehindNAT(PIPSocket::Address &) const;
@@ -633,7 +634,7 @@ private:
 	std::map<unsigned, unsigned> m_receivedCauseMap;
 	std::map<unsigned, unsigned> m_sentCauseMap;
 #ifdef HAS_H235_MEDIA
-	bool m_H235HalfCallMediaEnabled;
+	bool m_H235MediaEnabled;
 #endif
 	// is H460.18 enabled ?
 #ifdef HAS_H46018
