@@ -42,6 +42,7 @@ PIPSocket::Address GNUGK_INADDR_ANY(INADDR_ANY);
 
 PReadWriteMutex ConfigReloadMutex;
 
+#if PTRACING
 PTextFile* Gatekeeper::m_logFile = NULL;
 PFilePath Gatekeeper::m_logFilename;
 PMutex Gatekeeper::m_logFileMutex;
@@ -50,6 +51,7 @@ int Gatekeeper::m_rotateMinute = 0;
 int Gatekeeper::m_rotateHour = 0;
 int Gatekeeper::m_rotateDay = 0;
 GkTimer* Gatekeeper::m_rotateTimer = GkTimerManager::INVALID_HANDLE;
+#endif // PTRACING
 
 PSemaphore ShutdownMutex(1,1);
 
@@ -63,7 +65,9 @@ PString pidfile("/var/run/gnugk.pid");
 
 void ShutdownHandler()
 {
+#if PTRACING
 	Gatekeeper::EnableLogFileRotation(false);
+#endif
 	// delete singleton objects
 	PTRACE(3, "GK\tDeleting global reference tables");
 
@@ -82,7 +86,9 @@ void ShutdownHandler()
 		delete Toolkit::Instance();
 	PTRACE(3, "GK\tdelete ok");
 
+#if PTRACING
 	Gatekeeper::CloseLogFile();
+#endif
 }
 
 static const char * KnowConfigEntries[][2] = {
@@ -170,7 +176,6 @@ static const char * KnowConfigEntries[][2] = {
 	{ "Gatekeeper::Auth", "SimplePasswordAuth" },
 	{ "Gatekeeper::Auth", "default" },
 	{ "Gatekeeper::Main", "AlternateGKs" },
-	{ "Gatekeeper::Main", "Authenticators" },
 	{ "Gatekeeper::Main", "Bind" },
 	{ "Gatekeeper::Main", "CompareAliasCase" },
 	{ "Gatekeeper::Main", "CompareAliasType" },
@@ -190,7 +195,6 @@ static const char * KnowConfigEntries[][2] = {
 	{ "Gatekeeper::Main", "Home" },
 	{ "Gatekeeper::Main", "ListenQueueLength" },
 	{ "Gatekeeper::Main", "MaxASNArraySize" },
-	{ "Gatekeeper::Main", "MaximumBandwidthPerCall" },
 	{ "Gatekeeper::Main", "MinimumBandwidthPerCall" },
 	{ "Gatekeeper::Main", "MulticastGroup" },
 	{ "Gatekeeper::Main", "MulticastPort" },
@@ -225,13 +229,11 @@ static const char * KnowConfigEntries[][2] = {
 	{ "GkPresence::SQL", "Driver" },
 	{ "GkPresence::SQL", "Host" },
 	{ "GkPresence::SQL", "Library" },
-	{ "GkPresence::SQL", "Password" },
 	{ "GkPresence::SQL", "MinPoolSize" },
 	{ "GkPresence::SQL", "QueryAdd" },
 	{ "GkPresence::SQL", "QueryDelete" },
 	{ "GkPresence::SQL", "QueryList" },
 	{ "GkPresence::SQL", "QueryUpdate" },
-	{ "GkPresence::SQL", "Username" },
 	{ "GkQoSMonitor", "CallEndOnly" },
 	{ "GkQoSMonitor", "DetailFile" },
 	{ "GkQoSMonitor", "Enable" },
@@ -242,7 +244,6 @@ static const char * KnowConfigEntries[][2] = {
 	{ "GkQoSMonitor::SQL", "Library" },
 	{ "GkQoSMonitor::SQL", "Password" },
 	{ "GkQoSMonitor::SQL", "Query" },
-	{ "GkQoSMonitor::SQL", "Username" },
 	{ "GkStatus::Filtering", "Enable" },
 	{ "GkStatus::Filtering", "ExcludeFilter" },
 	{ "GkStatus::Filtering", "IncludeFilter" },
@@ -276,8 +277,6 @@ static const char * KnowConfigEntries[][2] = {
 	{ "Proxy", "RTPMultiplexPort" },
 	{ "Proxy", "RTCPMultiplexPort" },
 	{ "Proxy", "RTPPortRange" },
-	{ "Proxy", "RemoveMCInFastStartTransmitOffer" },
-	{ "Proxy", "SearchBothSidesOnCLC" },
 	{ "Proxy", "T120PortRange" },
 	{ "RadAcct", "AppendCiscoAttributes" },
 	{ "RadAcct", "DefaultAcctPort" },
@@ -348,22 +347,18 @@ static const char * KnowConfigEntries[][2] = {
 	{ "RoutedMode", "AcceptUnregisteredCalls" },
 	{ "RoutedMode", "ActivateFailover" },
 	{ "RoutedMode", "AlertingTimeout" },
-	{ "RoutedMode", "AlwaysRewriteSourceCallSignalAddress" },
 	{ "RoutedMode", "AutoProxyIPv4ToIPv6Calls" },
 	{ "RoutedMode", "CallSignalHandlerNumber" },
 	{ "RoutedMode", "CallSignalPort" },
-	{ "RoutedMode", "CalledTypeOfNumber" },
-	{ "RoutedMode", "CallingTypeOfNumber" },
 	{ "RoutedMode", "CpsCheckInterval" },
 	{ "RoutedMode", "CpsLimit" },
 	{ "RoutedMode", "DisableRetryChecks" },
 	{ "RoutedMode", "DropCallsByReleaseComplete" },
 	{ "RoutedMode", "ENUMservers" },
-	{ "RoutedMode", "EnableH235HalfCallMedia" },
+    { "RoutedMode", "EnableH235Media" },
 	{ "RoutedMode", "EnableH450.2" },
 	{ "RoutedMode", "EnableH46018" },
 	{ "RoutedMode", "EnableH46023" },
-	{ "RoutedMode", "EnableH460P" },
 	{ "RoutedMode", "FailoverCauses" },
 	{ "RoutedMode", "ForceNATKeepAlive" },
 	{ "RoutedMode", "ForwardOnFacility" },
@@ -380,7 +375,6 @@ static const char * KnowConfigEntries[][2] = {
 	{ "RoutedMode", "NATStdMin" },
 	{ "RoutedMode", "Q931PortRange" },
 	{ "RoutedMode", "RemoveCallOnDRQ" },
-	{ "RoutedMode", "RemoveFaxUDPOptionsFromRM" },
 	{ "RoutedMode", "RemoveH235Call" },
 	{ "RoutedMode", "RemoveH245AddressOnTunneling" },
 	{ "RoutedMode", "RemoveH460Call" },
@@ -400,7 +394,6 @@ static const char * KnowConfigEntries[][2] = {
 	{ "RoutedMode", "TranslateReceivedQ931Cause" },
 	{ "RoutedMode", "TreatUnregisteredNAT" },
 	{ "RoutedMode", "TranslateSentQ931Cause" },
-	{ "RoutedMode", "TranslateSorensonSourceInfo" },
 	{ "RoutedMode", "UseProvisionalRespToH245Tunneling" },
 	{ "Routing::CatchAll", "CatchAllAlias" },
 	{ "Routing::CatchAll", "CatchAllIP" },
@@ -453,14 +446,12 @@ static const char * KnowConfigEntries[][2] = {
 	{ "SQLAuth", "Password" },
 	{ "SQLAuth", "RegQuery" },
 	{ "SQLAuth", "Username" },
-	{ "SQLConfig", "CacheTimeout" },
 	{ "SQLConfig", "ConfigQuery" },
 	{ "SQLConfig", "Database" },
 	{ "SQLConfig", "Driver" },
 	{ "SQLConfig", "GWPrefixesQuery" },
 	{ "SQLConfig", "Host" },
 	{ "SQLConfig", "Library" },
-	{ "SQLConfig", "MinPoolSize" },
 	{ "SQLConfig", "NeighborsQuery" },
 	{ "SQLConfig", "Password" },
 	{ "SQLConfig", "PermanentEndpointsQuery" },
@@ -582,7 +573,6 @@ bool CheckConfig(PConfig * cfg, const PString & mainsection)
 			j++;
 		}
 		if (!found) {
-			cerr << "WARNING: Config section [" << sect << "] unknown" << endl;
 			PTRACE(0, "WARNING: Config section [" << sect << "] unknown");
 			warnings++;
 		} else if (!section_checkable) {
@@ -594,7 +584,6 @@ bool CheckConfig(PConfig * cfg, const PString & mainsection)
 				PCaselessString key = entries.GetKeyAt(j);
 				PString value = entries.GetDataAt(j);
 				if (value.IsEmpty()) {
-					cerr << "WARNING: Empty switch: [" << sect << "] " << key << "=" << endl;
 					PTRACE(0, "WARNING: Empty switch: [" << sect << "] " << key << "=");
 				}
 				unsigned k = 0;
@@ -608,7 +597,6 @@ bool CheckConfig(PConfig * cfg, const PString & mainsection)
 					}
 				}
 				if (!entry_found) {
-					cerr << "WARNING: Config entry [" << sect << "] " << key << "=" << value << " unknown" << endl;
 					PTRACE(0, "WARNING: Config entry [" << sect << "] " << key << "=" << value << " unknown");
 					warnings++;
 				}
@@ -627,11 +615,15 @@ bool CheckConfig(PConfig * cfg, const PString & mainsection)
 // or we get core dump
 void ExitGK()
 {
+#if PTRACING
 	Gatekeeper::EnableLogFileRotation(false);
+#endif
 
 	delete Toolkit::Instance();
 
+#if PTRACING
 	Gatekeeper::CloseLogFile();
+#endif
 	exit(0);
 }
 
@@ -702,7 +694,9 @@ BOOL WINAPI WinCtrlHandlerProc(DWORD dwCtrlType)
 
 	if( dwCtrlType == CTRL_LOGOFF_EVENT ) {
 		eventName = "CTRL_LOGOFF_EVENT";
+#if PTRACING
 		PTRACE(2,"GK\tGatekeeper received " <<eventName);
+#endif
 		// prevent shut down
 		return FALSE;
 	}
@@ -716,7 +710,7 @@ BOOL WINAPI WinCtrlHandlerProc(DWORD dwCtrlType)
 	else if( dwCtrlType == CTRL_SHUTDOWN_EVENT )
 		eventName = "CTRL_SHUTDOWN_EVENT";
 
-#ifndef hasPTLibTraceOnShutdownBug
+#if PTRACING
 	PTRACE(1,"GK\tGatekeeper shutdown due to "<<eventName);
 #endif
 
@@ -902,8 +896,10 @@ const PString Gatekeeper::GetArgumentsParseString() const
 #ifdef HAS_SETUSERNAME
 		 "u-user:"
 #endif
+#if PTRACING
 		 "t-trace."
 		 "o-output:"
+#endif
 		 "c-config:"
 		 "s-section:"
 		 "-pid:"
@@ -963,6 +959,7 @@ bool Gatekeeper::InitHandlers(const PArgList & args)
 
 bool Gatekeeper::InitLogging(const PArgList & args)
 {
+#if PTRACING
 	// Syslog is the default when compiled as service, but we don't want that
 	PTrace::ClearOptions(PTrace::SystemLogStream);
 	PTrace::SetOptions(PTrace::DateAndTime | PTrace::TraceLevel | PTrace::FileAndLine);
@@ -974,6 +971,7 @@ bool Gatekeeper::InitLogging(const PArgList & args)
 			return FALSE;
 		}
 	}
+#endif
 
 	return TRUE;
 }
@@ -1018,8 +1016,10 @@ void Gatekeeper::PrintOpts()
 #ifdef HAS_SETUSERNAME
 		"  -u  --user name    : Run as this user\n"
 #endif
+#if PTRACING
 		"  -t  --trace        : Set trace verbosity\n"
 		"  -o  --output file  : Write trace to this file\n"
+#endif
 		"  -c  --config file  : Specify which config file to use\n"
 		"  -s  --section sec  : Specify which main section to use in the config file\n"
 		"      --pid file     : Specify the pid file\n"
@@ -1106,8 +1106,6 @@ void Gatekeeper::Main()
 			fake_cmdline += " -o " + log_trace_file;
 	}
 	if (!fake_cmdline.IsEmpty()) {
-		for (int t=0; t < args.GetOptionCount('t'); t++)
-			fake_cmdline += " -t";
 		PArgList fake_args(fake_cmdline);
 		fake_args.Parse(GetArgumentsParseString());
 		InitLogging(fake_args);
@@ -1190,7 +1188,7 @@ void Gatekeeper::Main()
 	else if (args.HasOption('d'))
 		RasSrv->SetRoutedMode(false, false);
 #ifdef HAS_H235_MEDIA
-    else if (Toolkit::Instance()->IsH235HalfCallMediaEnabled()) 
+    else if (Toolkit::Instance()->IsH235MediaEnabled()) 
         RasSrv->SetRoutedMode(true, true);
 #endif 
 	else 
@@ -1219,7 +1217,9 @@ void Gatekeeper::Main()
 	// graceful shutdown
 	cerr << "\nShutting down gatekeeper . . . ";
 
-	ShutdownHandler();
+#if !defined(_WIN32) || PTLIB_VER < 2102
+	ShutdownHandler();    // <-- on Windows PTLIB 2.10.2 and 2.11.x shuting down worker threads segfaults
+#endif
 	cerr << "done\n";
 
 #ifdef _WIN32
@@ -1229,6 +1229,7 @@ void Gatekeeper::Main()
 #endif // _WIN32
 }
 
+#if PTRACING
 namespace {
 const char* const logConfigSectionName = "Logfile";
 }
@@ -1570,3 +1571,4 @@ void Gatekeeper::CloseLogFile()
 #endif
 	m_logFile = NULL;
 }
+#endif // PTRACING
