@@ -231,6 +231,7 @@ GkAuthenticator::GkAuthenticator(
 		}
 	}
 
+#if PTRACING
 	// convert bit flags to human readable names
 	PString rasFlagsStr, miscFlagsStr;
 	
@@ -262,6 +263,7 @@ GkAuthenticator::GkAuthenticator(
 	PTRACE(1, "GKAUTH\t" << GetName() << " rule added to check RAS: "
 		<< rasFlagsStr << ", OTHER: " << miscFlagsStr
 		);
+#endif	
 
 	m_h235Authenticators = NULL;
 }
@@ -830,6 +832,7 @@ void GkAuthenticatorList::OnReload()
 
 	if (mechanisms.GetSize() > 0 && algorithmOIDs.GetSize() > 0) {
 		if (PTrace::CanTrace(4)) {
+#if PTRACING
 			ostream& strm = PTrace::Begin(4,__FILE__,__LINE__);
 			strm <<"GkAuth\tH.235 capabilities selected for GCF:\n";
 			strm <<"\tAuthentication mechanisms: \n";
@@ -839,6 +842,7 @@ void GkAuthenticatorList::OnReload()
 			for (i = 0; i < algorithmOIDs.GetSize(); i++)
 				strm << "\t\t" << algorithmOIDs[i] << '\n';
 			PTrace::End(strm);
+#endif
 		}
 #ifdef OpenH323Factory
 	}
@@ -1161,6 +1165,11 @@ SimplePasswordAuth::~SimplePasswordAuth()
 	delete m_cache;
 }
 
+int SimplePasswordAuth::Check(RasPDU<H225_GatekeeperRequest> & request, unsigned &)
+{
+	return doCheck(request);
+}
+
 int SimplePasswordAuth::Check(
 	RasPDU<H225_RegistrationRequest> & request, 
 	RRQAuthData& /*authData*/
@@ -1654,10 +1663,12 @@ bool AliasAuth::doCheck(
 	)
 {
 	const PStringArray authrules(condition.Tokenise("&|", FALSE));
+#if PTRACING
 	if (authrules.GetSize() < 1) {
 		PTRACE(2, "GKAUTH\t" << GetName() << " contains an empty auth condition");
 		return false;
 	}
+#endif
 	for (PINDEX i = 0; i < authrules.GetSize(); ++i)
 		for (PINDEX j = 0; j < sigaddr.GetSize(); ++j)
 			if (CheckAuthRule(sigaddr[j], authrules[i])) {
@@ -1905,9 +1916,11 @@ public:
 		) : AuthRule(fate, inverted), m_pattern(aliasStr) 
 	{ 
 		m_priority = -1;
+#if PTRACING
 		SetName(PString((fate == e_allow) ? "allow alias" : "deny alias")
 			+ (inverted ? ":!" : ":") + aliasStr
 			);
+#endif
 	}
 
 	virtual bool Match(
@@ -2017,8 +2030,10 @@ IPAuthRule::IPAuthRule(Result fate, const PString & ipStr, bool inverted)
 	DWORD n = ~PIPSocket::Net2Host(DWORD(m_netmask));
 	for (m_priority = 0; n; n >>= 1)
 		++m_priority;
+#if PTRACING
 	SetName(PString((fate == e_allow) ? "allow ip(" : "deny ip(")
 		+ PString(m_priority) + (inverted ? "):!" : "):") + ipStr);
+#endif
 }
 
 bool IPAuthRule::Match(const AuthObj & aobj)
@@ -2221,6 +2236,7 @@ int PrefixAuth::doCheck(
 			}
 		}
 	}
+#if PTRACING
 	if (m_defaultRule == e_ok)
 		PTRACE(4, "GKAUTH\t" << GetName() << " default rule accepted "
 			"the request"
@@ -2233,6 +2249,7 @@ int PrefixAuth::doCheck(
 		PTRACE(4, "GKAUTH\t" << GetName() << " could not reject or "
 			"accept the request"
 			);
+#endif
 	return m_defaultRule;
 }
 
