@@ -14,7 +14,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef GKAUTH_H
-#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.55 2011/11/23 23:22:50 willamowius Exp $"
+#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.54 2011/03/30 11:27:15 willamowius Exp $"
 
 #include <map>
 #include <list>
@@ -527,7 +527,8 @@ class SimplePasswordAuth : public GkAuthenticator
 public:
 	enum SupportedRasChecks {
 		/// bitmask of RAS checks implemented by this module
-		SimplePasswordAuthRasChecks = RasInfo<H225_RegistrationRequest>::flag
+		SimplePasswordAuthRasChecks = RasInfo<H225_GatekeeperRequest>::flag
+			| RasInfo<H225_RegistrationRequest>::flag
 			| RasInfo<H225_UnregistrationRequest>::flag
 			| RasInfo<H225_BandwidthRequest>::flag
 			| RasInfo<H225_DisengageRequest>::flag
@@ -545,6 +546,7 @@ public:
 	virtual ~SimplePasswordAuth();
 
 	// overriden from class GkAuthenticator
+	virtual int Check(RasPDU<H225_GatekeeperRequest>& req, unsigned& rejectReason);
 	virtual int Check(RasPDU<H225_UnregistrationRequest>& req, unsigned& rejectReason);
 	virtual int Check(RasPDU<H225_BandwidthRequest>& req, unsigned& rejectReason);
 	virtual int Check(RasPDU<H225_DisengageRequest>& req, unsigned& rejectReason);
