@@ -13,7 +13,7 @@
 
 
 #ifndef H323UTIL_H
-#define H323UTIL_H "@(#) $Id: h323util.h,v 1.44 2011/12/21 17:02:07 willamowius Exp $"
+#define H323UTIL_H "@(#) $Id: h323util.h,v 1.43 2011/11/11 12:07:59 willamowius Exp $"
 
 #include <ptlib.h>
 #include <ptlib/sockets.h>
@@ -110,9 +110,6 @@ bool IsLoopback(const PIPSocket::Address &);
 
 bool IsSet(const H323TransportAddress & addr);
 
-// check if s only contains characters that are valid for E.164s (1234567890*#+,)
-bool IsValidE164(const PString & s);
-
 /** Find an alias which tag is of type specified by #primaryTags#.
     If no such aliases are found, #secondaryTags# are examined.
     If still no match is found and #exactMatch# is false, the first
