@@ -3,7 +3,7 @@
  *
  * IP based authentication modules
  *
- * @(#) $Id: ipauth.cxx,v 1.14 2011/11/28 12:33:41 willamowius Exp $
+ * @(#) $Id: ipauth.cxx,v 1.13 2011/09/02 10:09:25 willamowius Exp $
  *
  * Copyright (c) 2005, Michal Zygmuntowicz
  * Copyright (c) 2006-2010, Jan Willamowius
@@ -226,6 +226,7 @@ FileIPAuth::FileIPAuth(
 	
 	PTRACE(5, GetName() << "\t" << m_authList.size() << " entries loaded");
 
+#if PTRACING
 	if (PTrace::CanTrace(6)) {
 		ostream &strm = PTrace::Begin(6, __FILE__, __LINE__);
 		strm << GetName() << " entries:\n";
@@ -238,6 +239,7 @@ FileIPAuth::FileIPAuth(
 		}
 		PTrace::End(strm);
 	}
+#endif
 
 	if (dynamicCfg) {
 		delete cfg;
