@@ -19,7 +19,6 @@
 #include "stl_supp.h"
 #include "rwlock.h"
 #include "singleton.h"
-#include "config.h"
 #include "job.h"
 
 // timeout (seconds) for an idle Worker to be deleted
@@ -72,7 +71,7 @@ private:
 	Worker();
 	Worker(const Worker&);
 	Worker& operator=(const Worker&);
-
+	
 private:
 	/// idle timeout (seconds), after which the Worker is destoyed
 	PTimeInterval m_idleTimeout;
@@ -160,7 +159,6 @@ Worker::~Worker()
 	if (m_job) {
 		PTRACE(1, "JOB\tDestroying Worker " << m_id << " with active Job " << m_job->GetName());
 		delete m_job;
-		m_job = NULL;
 	}
 	PTRACE(5, "JOB\tWorker " << m_id << " destroyed");
 }
@@ -245,6 +243,7 @@ void Worker::Destroy()
 	
 	PTRACE(5, "JOB\tWaiting for Worker thread " << m_id << " termination");
 	WaitForTermination(5 * 1000);	// max. wait 5 sec.
+	delete this;
 }
 
 
@@ -257,15 +256,19 @@ Agent::~Agent()
 	PTRACE(5, "JOB\tDestroying active Workers for the Agent");
 
 	std::list<Worker*> workers;
+#if PTRACING
 	int numIdleWorkers = -1;
 	int numBusyWorkers = -1;
+#endif
 	
 	{
 		// move all workers to the local list
 		PWaitAndSignal lock(m_wlistMutex);
 		m_active = false;
+#if PTRACING
 		numIdleWorkers = m_idleWorkers.size();
 		numBusyWorkers = m_busyWorkers.size();
+#endif
 		while (!m_busyWorkers.empty()) {
 			workers.push_front(m_busyWorkers.front());
 			m_busyWorkers.pop_front();
@@ -276,27 +279,28 @@ Agent::~Agent()
 		}
 	}
 
+#if PTRACING
 	PTRACE(5, "JOB\tWorker threads to cleanup: " << (numBusyWorkers+numIdleWorkers) 
-		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle");
-
-	std::list<Worker*>::iterator iter = workers.begin();
-	while (iter != workers.end()) {
-		Worker * w = *iter;
-		workers.erase(iter++);
-		w->Destroy();
-#if !defined(_WIN32) || (PTLIB_VER <= 2100)
-		delete w;	// don't delete on Windows, issue with PTLib 2.10.1+
+		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle"
+		);
 #endif
-	}
+
+	// destroy all workers
+	ForEachInContainer(workers, mem_vfun(&Worker::Destroy));
 	
 	PTRACE(5, "JOB\tAgent and its Workers destroyed");
 }
 
-void Agent::Exec(Job * job)
+void Agent::Exec(
+	/// the job to be executed
+	Job* job
+	)
 {
 	Worker* worker = NULL;
+#if PTRACING
 	int numIdleWorkers = -1;
 	int numBusyWorkers = -1;
+#endif
 	// pop the first idle worker and move it to the busy list	
 	if (job) {
 		PWaitAndSignal lock(m_wlistMutex);
@@ -311,8 +315,10 @@ void Agent::Exec(Job * job)
 			worker = m_idleWorkers.front();
 			m_idleWorkers.pop_front();
 			m_busyWorkers.push_front(worker);
+#if PTRACING
 			numIdleWorkers = m_idleWorkers.size();
 			numBusyWorkers = m_busyWorkers.size();
+#endif
 		}
 	} else
 		return;
@@ -328,8 +334,10 @@ void Agent::Exec(Job * job)
 			m_busyWorkers.push_front(worker);
 		else
 			destroyWorker = true;
+#if PTRACING
 		numIdleWorkers = m_idleWorkers.size();
 		numBusyWorkers = m_busyWorkers.size();
+#endif
 	}
 	
 	// execute the job by the worker
@@ -343,12 +351,17 @@ void Agent::Exec(Job * job)
 			m_idleWorkers.push_front(worker);
 		else
 			destroyWorker = true;
+#if PTRACING
 		numIdleWorkers = m_idleWorkers.size();
 		numBusyWorkers = m_busyWorkers.size();
+#endif
 	}
 
+#if PTRACING
 	PTRACE_IF(5, m_active, "JOB\tWorker threads: " << (numBusyWorkers+numIdleWorkers) 
-		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle");
+		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle"
+		);
+#endif
 
 	if (destroyWorker) {
 		PTRACE(5, "JOB\tAgent did not accept Job " << job->GetName());
@@ -360,18 +373,23 @@ void Agent::Remove(
 	Worker* worker
 	)
 {
+#if PTRACING
 	int numIdleWorkers;
 	int numBusyWorkers;
 	{
+#endif
 		PWaitAndSignal lock(m_wlistMutex);
 		// check both lists for the worker
 		m_idleWorkers.remove(worker);
 		m_busyWorkers.remove(worker);
+#if PTRACING
 		numIdleWorkers = m_idleWorkers.size();
 		numBusyWorkers = m_busyWorkers.size();
 	}
 	PTRACE_IF(5, m_active, "JOB\tWorker threads: " << (numBusyWorkers+numIdleWorkers) 
-		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle");
+		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle"
+		);
+#endif
 }
 
 void Agent::JobDone(
@@ -379,18 +397,23 @@ void Agent::JobDone(
 	Worker* worker
 	)
 {
+#if PTRACING
 	int numIdleWorkers;
 	int numBusyWorkers;
 	{
+#endif
 		PWaitAndSignal lock(m_wlistMutex);
 		m_busyWorkers.remove(worker);
 		if (m_active)
 			m_idleWorkers.push_front(worker);
+#if PTRACING
 		numIdleWorkers = m_idleWorkers.size();
 		numBusyWorkers = m_busyWorkers.size();
 	}
 	PTRACE_IF(5, m_active, "JOB\tWorker threads: " << (numBusyWorkers+numIdleWorkers) 
-		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle");
+		<< " total - " << numBusyWorkers << " busy, " << numIdleWorkers << " idle"
+		);
+#endif
 }
 
 
