@@ -13,7 +13,7 @@
 
 
 #ifndef PWLIB_COMPAT_H
-#define PWLIB_COMPAT_H "@(#) $Id: pwlib_compat.h,v 1.51 2011/11/28 12:33:41 willamowius Exp $"
+#define PWLIB_COMPAT_H "@(#) $Id: pwlib_compat.h,v 1.50 2011/09/23 09:28:52 willamowius Exp $"
 
 #include "ptbuildopts.h"
 #include "openh323buildopts.h"
@@ -26,10 +26,6 @@
 	#endif
 #endif
 
-#ifndef PTRACING
-	#error "Enable PTRACING in PTLIB to compile GnuGk"
-#endif
-
 // check for PConfig support
 #ifndef P_CONFIG_FILE
 	#error "Make sure PTLib has config file support enabled, avoid --disable-configfile or --enable-openh323 or --enable-minsize etc."
@@ -110,9 +106,6 @@
 	#if PTLIB_MINOR >= 8
 		#define hasDynaLinkGetLastError 1
 	#endif
-	#if PTLIB_MINOR == 9
-		#define hasPTLibTraceOnShutdownBug	1
-	#endif
 	#if PTLIB_MINOR >= 10
 		#ifdef P_HAS_IPV6
 			// IPv6 support before 2.10.0 is too buggy
