@@ -101,9 +101,9 @@ RadAuthBase::~RadAuthBase()
 
 int RadAuthBase::Check(
 	/// RRQ RAS message to be authenticated
-	RasPDU<H225_RegistrationRequest> & rrqPdu, 
+	RasPDU<H225_RegistrationRequest>& rrqPdu, 
 	/// authorization data (reject reason, ...)
-	RRQAuthData & authData
+	RRQAuthData& authData
 	)
 {
 	H225_RegistrationRequest& rrq = (H225_RegistrationRequest&)rrqPdu;
@@ -170,6 +170,10 @@ int RadAuthBase::Check(
 			);
 	}
 	
+	if (!OnSendPDU(*pdu, rrqPdu, authData)) {
+		delete pdu;
+		return e_fail;
+	}
 	// send request and wait for response
 	RadiusPDU* response = NULL;
 	bool result = m_radiusClient->MakeRequest(*pdu, response) && response;
@@ -316,7 +320,9 @@ int RadAuthBase::Check(
 		}
 	}
 
-	if (!result)
+	if (result)
+		result = OnReceivedPDU(*response, rrqPdu, authData);
+	else
 		authData.m_rejectReason = H225_RegistrationRejectReason::e_securityDenial;
 				
 	delete response;
@@ -457,6 +463,10 @@ int RadAuthBase::Check(
 		pdu->AppendAttr(m_attrH323GwId);
 	}
 				
+	if (!OnSendPDU(*pdu, arqPdu, authData)) {
+		delete pdu;
+		return e_fail;
+	}
 	// send the request and wait for a response
 	RadiusPDU* response = NULL;
 	bool result = m_radiusClient->MakeRequest(*pdu, response) && response;
@@ -713,7 +723,9 @@ int RadAuthBase::Check(
 		}
 	}
 
-	if (!result)
+	if (result)
+		result = OnReceivedPDU(*response, arqPdu, authData);
+	else
 		authData.m_rejectReason = H225_AdmissionRejectReason::e_securityDenial;
 					
 	delete response;
@@ -823,6 +835,10 @@ int RadAuthBase::Check(
 		pdu->AppendAttr(m_attrH323GwId);
 	}
 				
+	if (!OnSendPDU(*pdu, setup, authData)) {
+		delete pdu;
+		return e_fail;
+	}
 	// send the request and wait for a response
 	RadiusPDU* response = NULL;
 	bool result = m_radiusClient->MakeRequest(*pdu, response) && response;
@@ -1027,7 +1043,9 @@ int RadAuthBase::Check(
 		}
 	}
 
-	if (!result)
+	if (result)
+		result = OnReceivedPDU(*response, setup, authData);
+	else
 		authData.m_rejectCause = Q931::CallRejected;
 					
 	delete response;
@@ -1035,6 +1053,60 @@ int RadAuthBase::Check(
 	return result ? e_ok : e_fail;
 }		
 
+bool RadAuthBase::OnSendPDU(
+	RadiusPDU& /*pdu*/,
+	RasPDU<H225_RegistrationRequest>& /*rrqPdu*/,
+	RRQAuthData& /*authData*/
+	)
+{
+	return true;
+}
+
+bool RadAuthBase::OnSendPDU(
+	RadiusPDU& /*pdu*/,
+	RasPDU<H225_AdmissionRequest>& /*arqPdu*/,
+	ARQAuthData& /*authData*/
+	)
+{
+	return true;
+}
+
+bool RadAuthBase::OnSendPDU(
+	RadiusPDU& /*pdu*/,
+	SetupMsg &/*setup*/,
+	SetupAuthData& /*authData*/
+	)
+{
+	return true;
+}
+
+bool RadAuthBase::OnReceivedPDU(
+	RadiusPDU& /*pdu*/,
+	RasPDU<H225_RegistrationRequest>& /*rrqPdu*/,
+	RRQAuthData& /*authData*/
+	)
+{
+	return true;
+}
+
+bool RadAuthBase::OnReceivedPDU(
+	RadiusPDU& /*pdu*/,
+	RasPDU<H225_AdmissionRequest>& /*arqPdu*/,
+	ARQAuthData& /*authData*/
+	)
+{
+	return true;
+}
+
+bool RadAuthBase::OnReceivedPDU(
+	RadiusPDU& /*pdu*/,
+	SetupMsg &/*setup*/,
+	SetupAuthData& /*authData*/
+	)
+{
+	return true;
+}
+
 int RadAuthBase::AppendUsernameAndPassword(
 	RadiusPDU& /*pdu*/,
 	RasPDU<H225_RegistrationRequest>& /*rrqPdu*/,
