@@ -3,23 +3,23 @@
 // slist.h
 //
 // A Single Linked List Template   *** LEGACY - use STL for new code ***
+// only used as parent for Policy class
 //
 // Copyright (c) Citron Network Inc. 2003
+// Copyright (c) 2006-2010, Jan Willamowius
 //
-// This work is published under the GNU Public License (GPL)
+// This work is published under the GNU Public License version 2 (GPLv2)
 // see file COPYING for details.
 // We also explicitly grant the right to link this code
-// with the OpenH323 library.
-//
-// initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
-// initial version: 07/16/2003
+// with the OpenH323/H323Plus and OpenSSL library.
 //
 //////////////////////////////////////////////////////////////////
 
 #ifndef SLIST_H
-#define SLIST_H "@(#) $Id: slist.h,v 1.5 2009/02/09 13:25:59 willamowius Exp $"
+#define SLIST_H "@(#) $Id: slist.h,v 1.11 2011/03/06 14:46:01 willamowius Exp $"
 
 #include "factory.h"
+#include <ptlib.h>
 
 template<class T>
 class SList {
@@ -41,6 +41,12 @@ SList<T>::~SList()
 	delete m_next;  // delete whole list recursively
 }
 
+
+// ignore overflow warning when comparing size
+#if (!_WIN32) && (GCC_VERSION >= 40400)
+#pragma GCC diagnostic ignored "-Wstrict-overflow"
+#endif
+
 template<class T>
 T *SList<T>::Create(const PStringArray & rules)
 {
