@@ -3,14 +3,14 @@
  *
  * SQL authentication/authorization modules for GNU Gatekeeper
  *
- * $Id: sqlauth.cxx,v 1.23 2009/09/21 06:30:18 willamowius Exp $
- *
  * Copyright (c) 2004, Michal Zygmuntowicz
+ * Copyright (c) 2006-2010, Jan Willamowius
  *
- * This work is published under the GNU Public License (GPL)
+ * This work is published under the GNU Public License version 2 (GPLv2)
  * see file COPYING for details.
  * We also explicitly grant the right to link this code
- * with the OpenH323 library.
+ * with the OpenH323/H323Plus and OpenSSL library.
+ *
  */
 
 #include <ptlib.h>
@@ -244,7 +244,7 @@ bool RunQuery(
 	if (result->GetNumRows() < 1)
 		PTRACE(3, traceStr << ": query returned no rows");
 	else if (result->GetNumFields() < 1)
-		PTRACE(2, traceStr << ": bad-formed query - "
+		PTRACE(2, traceStr << ": bad query - "
 			"no columns found in the result set"
 			);
 	else if (!result->FetchRow(resultRow) || resultRow.empty())
